#!/bin/bash
#
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# dernières révisions       : 22/02/2009 
#
#package			: pytube
#homepage			: http://www.bashterritory.com/pytube/
#source location	: http://marcosrodriguez.me/pytube/releases/pytube-0.0.11.5.gz
#dependency         : PyGTK 2,mplayer,mencoder, FFMPEG2Theora, Vorbis-Tools, FFMPEG 

softname='pytube'
softversion='0.0.11.5'
packageversion='60.1'

#
# ZenWalk standard: type CPUet architecture
#
# arch='i486' -> le compileur utilise seulement les instructions 80486
# cpu='i686'  -> optimisation faîte pour PII et >
#
arch='noarch'
cpu='i686'

#
# destination du package
#
prefix=/usr

#
# log
#
(

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "gros" PC: 6 compilations à la fois
#
# numjobs='-j6'
#
# "léger" PC: 2 compilations à la fois
#
numjobs='-j2'

#
# paramètres pour compiler
#
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://marcosrodriguez.me/pytube/releases/$softname-$softversion.tar.gz


#
# preparer le répertoire qui accueillera la compilation
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/$softname
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

#
# mettre le slack-desc en place. 
#
cat <<EOF > $dest/install/slack-desc 
      |-----handy-ruler------------------------------------------------------|
pytube: pytube - a tool to download YouTube videos for GNOME
pytube:
pytube: It allows you to resize, rotate, apply an external mp3 into a video,
pytube: generate a 10 to 30 seconds mp3 ring tone
pytube: 
pytube: 
pytube: 
pytube:
pytube:
pytube:
pytube:
EOF

#
# Verifie si package est present
#
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
tar xzvf $srcpkg
cd $src	

#
# "faire" le package package
#

cp -rv atom $dest/usr/share/$softname/
cp -rv gdata $dest/usr/share/$softname
cp -rv stream2hdd $dest/usr/share/$softname/
cp *.* $dest/usr/share/$softname
rm -v $dest/usr/share/$softname/LICENSE.txt $dest/usr/share/$softname/README $dest/usr/share/$softname/pytube.desktop

chmod 755 $dest/usr/share/$softname/atom
chmod -R 755 $dest/usr/share/$softname/atom/*
chmod 755 $dest/usr/share/$softname/gdata
chmod -R 755 $dest/usr/share/$softname/gdata/*
chmod 755 $dest/usr/share/$softname/pytube.py

# install le script YouTube
cp ../youtube-dl $dest/usr/bin
chmod a+x $dest/usr/bin/youtube-dl
   
#
# "faire" icon
#
cp -v ../pytube.png $dest/usr/share/icons/hicolor/48x48/apps/

# "faire" .desktop
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Encoding=UTF-8
Name=PyTube Multimedia Converter
GenericName=Multimedia Converter
Comment=Download and Convert Videos from YouTube.com
Exec=pytube
StartupNotify=false
Type=Application
Terminal=false
Categories=Application;AudioVideo;Audio;Multimedia;
Icon=pytube
EOF

cat <<EOF > $dest/usr/bin/pytube
#!/bin/sh
cd /usr/share/pytube/
./pytube.py "@"
EOF

chmod 755 $dest/usr/bin/pytube

#
# ajout des fichiers de docs, infos, ...
#
	cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      LICENSE.txt README\
      $dest/usr/doc/$softname-$softversion

#
# Mettre le zenbuild à sa place
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion
cp pytube.png $dest/$prefix/src/$softname-$softversion

#
# fixer les permissions
#
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#
# fabriquer le zenpackage
#
cd $dest
makepkg -l y -c n $dest.tgz

#
# produire la signature md5 du package
#
cd $buildir
md5sum $package.tgz > $package.md5

#
# produire le fichier .dep
#
cd $buildir
echo -e "ffmpeg,ffmpeg2theora,gtk+2,mencoder,mplayer,pygtk,python,sox,vorbis-tools" > $package.dep

#
# produire le fichier src
#
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/pytube/source/build-pytube.sh > $package.src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/pytube/source/youtube-dl >> $package.src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/pytube/source/pytube.png >> $package.src
echo $source >> $package.src

#
# supprimer source
#
rm -rf $src
rm -rf $dest

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
